==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/core/imultitypedataconsumer.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "imultitypedataconsumer.h"


#include "idata.h"
#include "idatareader.h"
#include "ierror.h"
#include "iviewmodule.h"


//
//  Templates
//
#include "iarraytemplate.h"


iMultiTypeDataConsumer::iMultiTypeDataConsumer(iViewModule *vm, const iDataInfo &info) : iDataConsumer(vm,iData::None())
{
	*mPrimaryDataInfo = info;
	mActiveDataTypeIndex = 0;
}


const iDataType& iMultiTypeDataConsumer::GetDataType() const
{
	return mPrimaryDataInfo->Type(mActiveDataTypeIndex);
}


void iMultiTypeDataConsumer::SetActiveDataType(const iDataType &type)
{
	this->SetActiveDataTypeIndex(mPrimaryDataInfo->Index(type));
}


bool iMultiTypeDataConsumer::IsActiveDataType(const iDataType &type) const
{
	return type == mPrimaryDataInfo->Type(mActiveDataTypeIndex);
}


void iMultiTypeDataConsumer::SetActiveDataTypeIndex(int v)
{
	if(v!=mActiveDataTypeIndex && v>=0 && v<mPrimaryDataInfo->Count())
	{
		int prev = mActiveDataTypeIndex;
		mActiveDataTypeIndex = v;
		this->UpdateDataType(prev);
		this->SyncWithData(this->Request(this->GetDataType()));
	}
}


int iMultiTypeDataConsumer::GetNumberOfTypes() const
{
	return mPrimaryDataInfo->Count();
}

==> ifrit_3.3.2.orig.tar.gz: ifrit-3.3.2/core/imultitypedataconsumer.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "imultitypedataconsumer.h"


#include "idata.h"
#include "idatareader.h"
#include "ierror.h"
#include "iviewmodule.h"


//
//  Templates
//
#include "iarraytemplate.h"


iMultiTypeDataConsumer::iMultiTypeDataConsumer(iViewModule *vm, const iDataInfo &info) : iDataConsumer(vm,iDataType::Null())
{
	*mPrimaryDataInfo = info;
	mActiveDataTypeIndex = 0;
}


const iDataType& iMultiTypeDataConsumer::GetDataType() const
{
	return mPrimaryDataInfo->Type(mActiveDataTypeIndex);
}


void iMultiTypeDataConsumer::SetActiveDataType(const iDataType &type)
{
	this->SetActiveDataTypeIndex(mPrimaryDataInfo->Index(type));
}


bool iMultiTypeDataConsumer::IsActiveDataType(const iDataType &type) const
{
	return type == mPrimaryDataInfo->Type(mActiveDataTypeIndex);
}


void iMultiTypeDataConsumer::SetActiveDataTypeIndex(int v)
{
	if(v!=mActiveDataTypeIndex && v>=0 && v<mPrimaryDataInfo->Count())
	{
		int prev = mActiveDataTypeIndex;
		mActiveDataTypeIndex = v;
		this->UpdateDataType(prev);
		this->SyncWithData(this->Request(this->GetDataType()));
	}
}


int iMultiTypeDataConsumer::GetNumberOfTypes() const
{
	return mPrimaryDataInfo->Count();
}
